@@ -18,6 +18,10 @@ from backlash.tbtools import get_current_traceback, render_console_html
 from backlash.console import Console
 from backlash.utils import gen_salt, RequestContext
 
+import logging
+log = logging.getLogger('backlash')
+
+
 class _ConsoleFrame(object):
     """Helper class so that we can reuse the frame console code for the
     standalone console.
@@ -72,20 +76,20 @@ class DebuggedApplication(object):
         """Run the application and conserve the traceback frames."""
         app_iter = None
         try:
-            app_iter = self.app(environ, start_response)
-            for item in app_iter:
-                yield item
-            if hasattr(app_iter, 'close'):
-                app_iter.close()
+            try:
+                app_iter = self.app(environ, start_response)
+                for item in app_iter:
+                    yield item
+            finally:
+                if hasattr(app_iter, 'close'):
+                    app_iter.close()
         except Exception:
-            if hasattr(app_iter, 'close'):
-                app_iter.close()
-
             context = RequestContext({'environ':dict(environ)})
             for injector in self.context_injectors:
                 context.update(injector(environ))
 
-            traceback = get_current_traceback(skip=1, show_hidden_frames=self.show_hidden_frames, context=context)
+            traceback = get_current_traceback(skip=1, show_hidden_frames=self.show_hidden_frames,
+                                              context=context)
             for frame in traceback.frames:
                 self.frames[frame.id] = frame
             self.tracebacks[traceback.id] = traceback
@@ -107,10 +111,15 @@ class DebuggedApplication(object):
                     'response at a point where response headers were already '
                     'sent.\n')
             else:
-                yield traceback.render_full(evalex=self.evalex,
-                    secret=self.secret)\
-                .encode('utf-8', 'replace')
+                yield traceback.render_full(
+                    evalex=self.evalex,
+                    secret=self.secret
+                ).encode('utf-8', 'replace')
 
+            # This will lead to double logging in case backlash logger is set to DEBUG
+            # but this is actually wanted as some environments, like WebTest, swallow
+            # wsgi.environ making the traceback totally disappear.
+            log.debug(traceback.plaintext)
             traceback.log(environ['wsgi.errors'])
 
     def execute_command(self, request, command, frame):
