@@ -20,10 +20,10 @@ from tokenize import TokenError
 from backlash.utils import escape
 from backlash.console import Console
 
-from backlash._compat import text_, native_, string_types, text_type, exec_, urlopen
+from backlash._compat import PY2, text_, native_, string_types, text_type, exec_, urlopen
 
 _coding_re = re.compile(r'coding[:=]\s*([-\w.]+)')
-_line_re = re.compile(r'^(.*?)$(?m)')
+_line_re = re.compile(r'^(.*?)$', re.MULTILINE)
 _funcdef_re = re.compile(r'^(\s*def\s)|(.*(?<!\w)lambda(:|\s))|^(\s*@)')
 UTF8_COOKIE = '\xef\xbb\xbf'
 
@@ -142,13 +142,16 @@ def render_console_html(secret):
     }
 
 
-def get_current_traceback(show_hidden_frames=False, skip=0, context=None):
+def get_current_traceback(show_hidden_frames=False, skip=0, context=None, exc_info=None):
     """Get the current exception info as `Traceback` object.  Per default
     calling this method will reraise system exceptions such as generator exit,
     system exit or others.  This behavior can be disabled by passing `False`
     to the function as first parameter.
     """
-    exc_type, exc_value, tb = sys.exc_info()
+    if exc_info is None:
+        exc_info = sys.exc_info()
+
+    exc_type, exc_value, tb = exc_info
     for x in range(skip):
         if tb.tb_next is None:
             break
@@ -192,6 +195,7 @@ class Traceback(object):
     def __init__(self, exc_type, exc_value, tb, context=None):
         self.exc_type = exc_type
         self.exc_value = exc_value
+        self.exc_info = (exc_type, exc_value, tb,)
         self.context = context
 
         if not isinstance(exc_type, str):
@@ -260,12 +264,9 @@ class Traceback(object):
         if logfile is None:
             logfile = sys.stderr
         tb = self.plaintext.rstrip() + '\n'
-
-        file_mode = getattr(logfile, 'mode', None)
-        if file_mode is not None:
-            if 'b' in file_mode:
-                tb = tb.encode('utf-8')
-            logfile.write(tb)
+        if PY2:
+            tb = tb.encode('utf-8')
+        logfile.write(tb)
 
     def paste(self):
         """Create a paste and return the paste id."""
